@@ -29,7 +29,7 @@ class Q_DECL_HIDDEN Ldif::LdifPrivate
 public:
     int mModType;
     bool mDelOldRdn, mUrl;
-    LdapDN mDn;
+    QByteArray mDn;
     QString mAttr, mNewRdn, mNewSuperior, mOid;
     QByteArray mLdif, mValue;
     EntryType mEntryType;
@@ -125,7 +125,6 @@ QByteArray Ldif::assembleLine(const QString &fieldname, const QString &value, ui
 bool Ldif::splitLine(const QByteArray &line, QString &fieldname, QByteArray &value)
 {
     int position;
-    QByteArray tmp;
     int linelen;
 
 //  qCDebug(KCONTACTS_LOG) << "line:" << QString::fromUtf8(line);
@@ -215,7 +214,7 @@ Ldif::ParseValue Ldif::processLine()
             }
         } else if (attrLower == QLatin1String("dn")) {
             qCDebug(KCONTACTS_LOG) << "ldapentry dn:" << QString::fromUtf8(d->mValue);
-            d->mDn = LdapDN(QString::fromUtf8(d->mValue));
+            d->mDn = d->mValue;
             d->mModType = Mod_None;
             retval = NewEntry;
         } else if (attrLower == QLatin1String("changetype")) {
@@ -371,7 +370,6 @@ void Ldif::startParsing()
     d->mDelOldRdn = false;
     d->mEntryType = Entry_None;
     d->mModType = Mod_None;
-    d->mDn = LdapDN();
     d->mNewRdn.clear();
     d->mNewSuperior.clear();
     d->mLine = QByteArray();
@@ -396,11 +394,6 @@ int Ldif::modType() const
     return d->mModType;
 }
 
-LdapDN Ldif::dn() const
-{
-    return d->mDn;
-}
-
 QString Ldif::newRdn() const
 {
     return d->mNewRdn;
